README.rst

# Statechart

Add statecharts to Odoo models.

Table of contents

- Usage
- Bug Tracker
- Credits
  - Authors
  - Maintainers

## Usage

There is no documentation yet. In the meantime here are the Odoo Experience 2018 slides and video which should get you started.

See also the sismic documentation.

## Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us to smash it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

## Credits

### Authors

- ACSONE SA/NV

### Maintainers

This module is part of the acsone/scobidoo project on GitHub.

You are welcome to contribute.